@@ -26,32 +26,34 @@ Cdqrls_res Cdqrls_wrapper(const arma::mat &X, const arma::vec &y,
 }
 
 using uword = arma::uword;
-arma::vec IWLS(const arma::mat &X, const arma::vec &y,
-               arma::vec beta, dist_family const * const family,
-               const arma::vec offsets,
-               const uword it_max = 1e3, const double eps = 1.0e-4){
+template<class T>
+arma::vec IWLS(
+    const arma::mat &X, const arma::vec &y,
+    arma::vec beta,
+    const arma::vec offsets,
+    const uword it_max = 1e3, const double eps = 1.0e-4){
 
   arma::vec weights(y.n_elem, arma::fill::ones);
   arma::vec eta = X * beta + offsets;
   arma::vec mu = eta;
-  mu.for_each([&](arma::mat::value_type &val) { val = family->link_func_inv(val); });
+  mu.for_each([&](arma::mat::value_type &val) { val = T::link_func_inv(val); });
 
   double deviance_old = 0.0;
   for(unsigned int i = 0; i < y.size(); i++)
-    deviance_old += family->dev_resids(y[i], mu[i], weights[i]);
+    deviance_old += T::dev_resids(y[i], mu[i], weights[i]);
 
   unsigned int it = 0;
   bool converged = false;
   while(!converged && it < it_max){
     arma::vec d_mu_d_eta = eta;
-    d_mu_d_eta.for_each([&](arma::vec::elem_type &val) { val = family->d_mu_d_eta(val); });
+    d_mu_d_eta.for_each([&](arma::vec::elem_type &val) { val = T::d_mu_d_eta(val); });
 
     arma::uvec good = arma::find((weights > 0) && (d_mu_d_eta != 0));
     if(good.n_elem < y.n_elem)
       Rcpp::warning("Some values 'IWLS' either had zero weights or mu = 0");
 
     arma::vec variance = mu.elem(good);
-    variance.for_each([&](arma::vec::elem_type &val) { val = family->variance(val); });
+    variance.for_each([&](arma::vec::elem_type &val) { val = T::variance(val); });
 
     arma::vec z = (eta.elem(good) - offsets.elem(good)) + (y.elem(good) - mu.elem(good)) / d_mu_d_eta.elem(good);
 
@@ -65,11 +67,11 @@ arma::vec IWLS(const arma::mat &X, const arma::vec &y,
 
     eta = X * beta + offsets;
     mu = eta;
-    mu.for_each([&](arma::mat::value_type &val) { val = family->link_func_inv(val); });
+    mu.for_each([&](arma::mat::value_type &val) { val = T::link_func_inv(val); });
 
     double deviance = 0.0;
     for(unsigned int i = 0; i < y.size(); i++)
-      deviance += family->dev_resids(y[i], mu[i], weights[i]);
+      deviance += T::dev_resids(y[i], mu[i], weights[i]);
 
     if (std::abs(deviance - deviance_old) / (0.1 + std::abs(deviance)) < eps) {
       converged = true;
@@ -93,7 +95,7 @@ arma::vec IWLS_logit(const arma::mat &X, const arma::vec &y,
                      arma::vec beta,
                      const arma::vec offsets,
                      const arma::uword it_max = 1e3, const double eps = 1.0e-4){
-  return(IWLS(X, y, beta, new logit_fam(), offsets, it_max, eps));
+  return(IWLS<logit_fam>(X, y, beta, offsets, it_max, eps));
 }
 
 // The export is only for internal test against glm.fit
@@ -102,5 +104,5 @@ arma::vec IWLS_poisson(const arma::mat &X, const arma::vec &y,
                        arma::vec beta,
                        const arma::vec offsets,
                        const arma::uword it_max = 1e3, const double eps = 1.0e-4){
-  return(IWLS(X, y, beta, new poisson_fam(), offsets, it_max, eps));
+  return(IWLS<poisson_fam>(X, y, beta, offsets, it_max, eps));
 }
